@@ -4,6 +4,14 @@ from elifecrossref import elife
 
 def generate_resource_url(obj, poa_article, crossref_config, pattern_type=None):
     # Generate a resource value for doi_data based on the object provided
+
+    # by default use the self-uri value of an Article first
+    if not isinstance(obj, Component):
+        for self_uri in obj.self_uri_list:
+            # get it from the self-uri value that has no content_type
+            if self_uri.content_type is None:
+                return self_uri.xlink_href
+
     if isinstance(obj, Component) or pattern_type == "peer_review_doi_pattern":
         if (
             pattern_type == "component_doi_pattern"
@@ -29,9 +37,5 @@ def generate_resource_url(obj, poa_article, crossref_config, pattern_type=None):
                 volume=obj.volume,
                 version=version,
             )
-        # if no doi_pattern is specified, try to get it from the self-uri value
-        #  that has no content_type
-        for self_uri in obj.self_uri_list:
-            if self_uri.content_type is None:
-                return self_uri.xlink_href
+
     return ""
